@@ -67,7 +67,7 @@ setConstructorS3("Arguments", function(...) {
 #
 # \references{
 #   [1] Microsoft, \emph{Naming Files, Paths, and Namespaces}, 2018.
-#       \url{https://docs.microsoft.com/en-us/windows/win32/fileio/naming-a-file}.
+#       \url{https://learn.microsoft.com/en-us/windows/win32/fileio/naming-a-file}.
 # }
 #
 # @author
@@ -1373,5 +1373,5 @@ withoutGString <- function(..., envir=parent.frame()) {
   # Temporarily disable 'asGString' for Arguments$getCharacters()
   oopts <- options("Arguments$getCharacters/args/asGString"=FALSE)
   on.exit(options(oopts))
-  eval(..., envir=envir)
+  eval(..., envir = envir, enclos = baseenv())
 } # withoutGString()
